# remirepo/fedora spec file for php-pear-CAS
#
# Copyright (c) 2010-2019 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global gh_commit    40c0769ce05a30c8172b36ceab11124375c8366e
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner     apereo
%global gh_project   phpCAS


Name:           php-pear-CAS
Version:        1.3.8
Release:        1%{?dist}
Summary:        Central Authentication Service client library in php

Group:          Development/Libraries
License:        ASL 2.0
URL:            https://wiki.jasig.org/display/CASC/phpCAS

Source0:        https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{name}-%{version}-%{?gh_short}.tar.gz

# From phpcompatinfo report, session_status is 5.4 only
Patch0:         %{name}-php53.patch

BuildArch:      noarch
BuildRequires:  php-fedora-autoloader-devel
# only for pear macros
BuildRequires:  php-pear
# for %%check
BuildRequires:  php-cli

Requires:       php-curl
Requires:       php-date
Requires:       php-dom
Requires:       php-hash
Requires:       php-pcre
Requires:       php-pdo
Requires:       php-session
Requires:       php-spl
# Optional: php-imap (when use Proxied Imap)
Requires:       php-composer(fedora/autoloader)

Provides:       php-pear(__uri/CAS) = %{version}
Provides:       php-composer(jasig/phpcas) = %{version}
Provides:       php-composer(apereo/phpcas) = %{version}
# this library is mostly known as phpCAS
Provides:       phpCAS = %{version}-%{release}


%description
This package is a PEAR library for using a Central Authentication Service.

Autoloader '%{pear_phpdir}/CAS/Autoload.php';


%prep
%setup -q -n %{gh_project}-%{gh_commit}

%patch0 -p0 -b .php53
find source -name \*.php53 -delete -print


%build
# Rewrite a classmap autoloader (upstream is broken)
%{_bindir}/phpab \
    --template fedora \
    --output source/CAS/Autoload.php  \
             source


%install
mkdir -p %{buildroot}%{pear_phpdir}
cp -pr source/* %{buildroot}%{pear_phpdir}/


%check
: Ensure our autoloader works
php -r '
require "%{buildroot}%{pear_phpdir}/CAS/Autoload.php";
if (!class_exists("phpCAS")) {
  echo "Class not found\n";
  exit(1);
}
if (phpCAS::getVersion() != "%{version}") {
  echo "Bad version (found=" . phpCAS::getVersion()  . ", expected=%{version})\n";
  exit(1);
}
echo "Ok\n";
'


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc composer.json
%doc NOTICE *.md
%{pear_phpdir}/CAS
%{pear_phpdir}/CAS.php


%changelog
* Thu Aug 22 2019 Remi Collet <remi@remirepo.net> - 1.3.8-1
- update to 1.3.8

* Tue Apr 23 2019 Remi Collet <remi@remirepo.net> - 1.3.7-1
- update to 1.3.7

* Fri Oct 26 2018 Remi Collet <remi@remirepo.net> - 1.3.6-1
- update to 1.3.6
- new github and packagist owner

* Tue Apr 11 2017 Remi Collet <remi@remirepo.net> - 1.3.5-1.1
- update to 1.3.5
- sources from github
- add minimal check for our autoloader
- add patch to fix compatibility with PHP 5.3

* Wed Oct 19 2016 Remi Collet <remi@fedoraproject.org> - 1.3.4-3
- fix broken autoloader

* Tue Nov 17 2015 Remi Collet <remi@fedoraproject.org> - 1.3.4-1
- update to Version 1.3.4
- add provides php-composer(jasig/phpcas)

* Mon Jul 28 2014 Remi Collet <remi@fedoraproject.org> - 1.3.4-1
- update to Version 1.3.3

* Sat Dec 29 2012 Remi Collet <remi@fedoraproject.org> - 1.3.2-1
- update to Version 1.3.2, security fix for
  CVE-2012-5583 Missing CN validation of CAS server certificate
- add requires for all needed php extensions

* Wed Mar 14 2012 Remi Collet <remi@fedoraproject.org> - 1.3.0-2
- License is ASL 2.0, https://github.com/Jasig/phpCAS/issues/32
- New sources,        https://github.com/Jasig/phpCAS/issues/31
- update to Version 1.3.0

* Sat Jun 11 2011 Remi Collet <Fedora@FamilleCollet.com> - 1.2.2-1
- update to Version 1.2.2 (stable) - API 1.2.2 (stable)
- dont requires domxml-php4-to-php5 anymore
- fix URL
- link %%doc to pear_docdir

* Mon Oct 04 2010 Remi Collet <Fedora@FamilleCollet.com> - 1.1.3-1
- update to 1.1.3
- fix CVE-2010-3690, CVE-2010-3691, CVE-2010-3692
- set timezone during build

* Tue Aug 03 2010 Remi Collet <Fedora@FamilleCollet.com> - 1.1.2-1
- update to 1.1.2
- fix  CVE-2010-2795, CVE-2010-2796, #620753

* Thu May 20 2010 Remi Collet <Fedora@FamilleCollet.com> - 1.1.1-1
- update to 1.1.1

* Thu May 20 2010 Remi Collet <Fedora@FamilleCollet.com> - 1.1.0-1
- update to 1.1.0 finale

* Sun Mar 14 2010 Remi Collet <Fedora@FamilleCollet.com> - 1.1.0-0.1.RC7
- initial packaging (using pear make-rpm-spec CAS-1.1.0RC7.tgz)

